import pygame, sys
from pygame.locals import *
from levels import Levels
from colors import colors
from player import Player
from tile import Tile
from coin import Coin_
from ghost import Ghost
from power_up import Power_up
pygame.init()
"""
state 0: Das script wird ausgeführt
state 1: das Menü
state 2: das Spiel
state 3: Game Over
"""
class Game():
    def __init__(self):
        self.state = 0
        self.levels = Levels()
        self.player = None
        self.font_start = pygame.font.Font("freesansbold.ttf", 40)
        self.pixel = self.levels.pixel
        self.width = self.levels.len_x*self.pixel
        self.height = self.levels.len_y*self.pixel
        self.background_color = colors.black
        self.tile_color = colors.blue
        self.time = 0
        self.tiles = []
        self.coins = []
        self.power_ups = []
        self.ghosts = []
        self.power_up_backup = []
        self.ghost_backup = []
        self.coin_backup = []
        self.all_sprites = pygame.sprite.Group()
        self.fps = 60
        self.clock = pygame.time.Clock()
        self.level = 1
        self.menu_anim = 1000
        self.points = 0
        self.points_backup = self.points
    def open_menu(self):
        self.window = pygame.display.set_mode((self.width, self.height))
        self.text_menu = self.font_start.render("Press any key to start", True, colors.white)
        self.text_menu2 = self.font_start.render("Arcade", True, colors.blue)
        self.text_menu_color = colors.white
        self.text_menu_pos = self.text_menu.get_rect(center=(self.width/2, self.height/2+60))
        self.text_menu2_pos = self.text_menu2.get_rect(center=(self.width/2, self.height/2-60))
        self.timer = pygame.time.get_ticks()
    def open_game_over(self):
        self.text_game_over = self.font_start.render("You reached level "+str(self.level), True, colors.white)
        self.text_game_over2 = self.font_start.render("Game Over", True, colors.blue)
        self.text_game_over_color = colors.white
        self.text_game_over_pos = self.text_game_over.get_rect(center=(self.width/2, self.height/2))
        self.text_game_over2_pos = self.text_game_over2.get_rect(center=(self.width/2, self.height/2-120))
        self.timer = pygame.time.get_ticks()
        self.text_game_over3 = self.font_start.render("Points: "+str(self.points_backup), True, colors.white)
        self.text_game_over3_pos = self.text_game_over3.get_rect(center=(self.width/2, self.height/2+120))
    def clear_window(self):
        self.window.fill(self.background_color)
        self.all_sprites.empty()
        self.tiles.clear()
        self.ghosts.clear()
        self.coins.clear()
        self.ghost_backup.clear()
    def load_level(self):
        self.clear_window()
        for y in range(0, self.levels.len_y):
            for x in range(0, self.levels.len_x):
                matrix = (self.levels.level1)[y][x]
                if matrix == "b":
                    self.tile = Tile(x, y, pygame.rect.Rect(x*self.pixel, y*self.pixel, self.pixel, self.pixel), colors.blue, self.pixel)
                    self.tiles.append(self.tile)
                if matrix == "-":
                    self.coin = Coin_(x*self.pixel, y*self.pixel, int(self.pixel/2), x, y, pygame.image.load("sprites/coin.png"))
                    self.coins.append(self.coin)
                    self.coin_backup.append(self.coin)
                if matrix == "+":
                    self.power_up = Power_up(x*self.pixel, y*self.pixel, x, y, int(self.pixel/2), pygame.image.load("sprites/power_up.png"))
                    self.power_ups.append(self.power_up)
                    self.power_up_backup.append(self.power_up)
                if matrix == "g":
                    self.ghost = Ghost(x*self.pixel, y*self.pixel, x, y, 3, self.pixel, pygame.image.load("sprites/ghost.png"))
                    self.ghost.game = self
                    self.ghosts.append(self.ghost)
                    self.ghost_backup.append(self.ghost)
                if matrix == "p":
                    self.player = Player(x*self.pixel, y*self.pixel, 3, 200, self.pixel, x, y, pygame.image.load("sprites/player.png"), 3)
                    self.player.game = self
        for coin in self.coins:
            self.all_sprites.add(coin)
        for power_up in self.power_ups:
            self.all_sprites.add(power_up)
        for ghost in self.ghosts:
            self.all_sprites.add(ghost)
        self.all_sprites.add(self.player)
    def update(self):
        self.ghosts.clear()
        self.points_backup = self.points
        self.points = 0
        if self.state == 0:
            self.state = 1
            pygame.display.set_caption("Menu")
            self.open_menu()
            return
        if self.state == 1:
            self.state = 2
            self.load_level()
            return
        if self.state == 3:
            pygame.display.set_caption("Game Over")
            self.open_game_over()
            return 
if __name__ == "__main__":
    sys.exit()
